@@ -6,11 +6,12 @@ import re
 
 NW = re.compile(r'\W')
 
-def GetLinks(url, proxy=None, text=False):
+def GetLinks(url, proxy=None,domain=None, text=False):
     doc = None
     basehost = None
     if url.startswith("http"):
-        basehost = up.urlsplit(url).hostname 
+        basehost = up.urlsplit(url).hostname
+        domain = basehost
         sess = requests.Session()
         if proxy != None:
             sess.proxies['http'] = sess.proxies['https'] = proxy
@@ -29,7 +30,10 @@ def GetLinks(url, proxy=None, text=False):
     for l in doc("a[href]"):
         link = l.attrib['href']
         if link  == "#":continue
+            
         if link.startswith("http") or link.startswith("//"):
+            if domain is not None and up.urlsplit(link).hostname != domain:
+                continue
             if not text:
                 res = up.urlsplit(url)
                 if basehost != None and res.hostname != basehost:continue
@@ -50,6 +54,13 @@ class Url(str):
         # self._like = []
         Url.urls[self.url] = self
 
+    def set_title(self, tt):
+        self.title = tt
+        if tt is None:
+            self.rank -= 3
+        else:
+            self.rank += len(tt) // 6
+
     def __sub__(self, other):
         if isinstance(other, str):
             other = Url(other)
@@ -119,16 +130,18 @@ class Url(str):
                 ui = Url(i)
             else:
                 ui = Url(i[0])
-                ui.title = i[1]
+                
+                ui.set_title(i[1])
+                
                 i = i[0]
             
             urls_g[i] = set()
             for ii in urls:
-                if isinstance(i, str):
+                if isinstance(ii, str):
                     ui2 = Url(ii)
                 else:
                     ui2 = Url(ii[0])
-                    ui2.title = ii[1]
+                    ui2.set_title(ii[1])
                     ii = ii[0]
                 
                 d = ui - ui2 
